## 期货历史分钟行情

接口：ft_mins

描述：获取全市场期货合约分钟数据，支持1min/5min/15min/30min/60min行情，提供Python SDK和 http Restful API两种方式，如果需要主力合约分钟，请先通过主力mapping接口获取对应的合约代码后提取分钟。

限量：单次最大8000行数据，可以通过期货合约代码和时间循环获取，本接口可以提供超过10年历史分钟数据。

权限：120积分可以调取2次接口查看数据，正式权限请参阅 权限说明  。

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 股票代码，e.g.CU2310.SHF |
| freq | str | Y | 分钟频度（1min/5min/15min/30min/60min） |
| start_date | datetime | N | 开始日期 格式：2023-08-25 09:00:00 |
| end_date | datetime | N | 结束时间 格式：2023-08-25 19:00:00 |

freq参数说明

| freq | 说明 |
| --- | --- |
| 1min | 1分钟 |
| 5min | 5分钟 |
| 15min | 15分钟 |
| 30min | 30分钟 |
| 60min | 60分钟 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 股票代码 |
| trade_time | str | Y | 交易时间 |
| open | float | Y | 开盘价 |
| close | float | Y | 收盘价 |
| high | float | Y | 最高价 |
| low | float | Y | 最低价 |
| vol | int | Y | 成交量 |
| amount | float | Y | 成交金额 |
| oi | float | Y | 持仓量 |

接口用法

```python
pro = ts.pro_api()

df = pro.df = pro.ft_mins(ts_code='CU2310.SHF', freq='1min', start_date='2023-08-25 09:00:00', end_date='2023-08-25 19:00:00')
```

数据样例

```python
ts_code           trade_time     open    close     high      low    vol       amount        oi
0    CU2310.SHF  2023-08-25 15:00:00  68920.0  68930.0  68940.0  68910.0  373.0  128543250.0  146733.0
```